import os
import sys
from testindatadev.TDA import TDA
import json

T_key = "1f25eddfeefc374a49e7c125341a6b3f"
ip = "http://10.10.32.54/"

tda = TDA(T_key, debug=True)

tda.Debug()

dataset = tda.SetDataset("ds_we2r3pqtdhz4nciurso3", ip)


dataDir = "/Users/hejinlong/Desktop/数据集测试数据/点云非融合数据/pcd"

for root, dirs, files in os.walk(dataDir):
    for filename in files:
        if filename.endswith(".pcd"):
            frame = filename.replace(".pcd", "")

            metaData = {
                "myfid": frame,
                "from": "DJ",
                "mykey": "test_" + frame
            }

            #标注结果
            jsonPath = os.path.join("/Users/hejinlong/Desktop/数据集测试数据/点云非融合数据/label", frame + ".json")
            with open(jsonPath) as rjf:
                markData = json.load(rjf)


            #添加点云文件
            pcdPath = os.path.join(root, filename)
            pcdFile = tda.AddFile(pcdPath, referId=frame + ".pcd", metaData=metaData)

            #点云添加标注结果
            for mark in markData["marks"]:
                box3d = {
                    "position": {
                        "x": mark["position"]["x"],
                        "y": mark["position"]["y"],
                        "z": mark["position"]["z"],
                    },
                    "scale": {
                        "x": mark["scale"]["x"],
                        "y": mark["scale"]["y"],
                        "z": mark["scale"]["z"],
                    },
                    "rotation": {
                        "x": mark["rotation"]["x"],
                        "y": mark["rotation"]["y"],
                        "z": mark["rotation"]["z"],
                    }
                }

                label = mark["property"][0][0]["ptitle"]
                instance = mark["objectId"]

                attr = {
                    "type":mark["property"][0][0]["ptitle"],
                    "carried":mark["property"][1][1]["ptitle"],
                    "lied":mark["property"][1][3]["ptitle"],
                    "crowd":mark["property"][1][5]["ptitle"],
                }


                pcdFile.AddBox3D(box3d, label=label, instance=instance, attrs=attr)


print(tda.Upload())



from testindatadev.TDA import TDA

T_key = "0fbe149adf07e5f4afa01a7a4e787fde"
ip = "10.32.144.73"

tda = TDA(T_key, debug=True)

tda.Debug()

dataset = tda.SetDataset("ds_7_hxflkjegen8hmucubk", ip)

metaData = {
    "metaKey1":"metaVal1",
    "metaKey2":"metaVal2",
    "metaKey3":"metaVal3",
}

file = tda.AddFile("/Users/hejinlong/Desktop/test_pic/11.jpg", referId="myTestRefId", metaData=metaData)

box = {
    "x": 10,
    "y": 10,
    "width": 100,
    "height": 100,
}

label = "myTestLabelName"

attr = {
    "attrKey1":"attrVal1",
    "attrKey2":"attrVal2",
    "attrKey3":"attrVal3",
}

file.AddBox2D(box, label=label, attrs=attr)

print(tda.Upload())



import os
import json

from testindatadev.TDA import TDA

#初始化TDA
#测试
T_key = "9e819cc1596ab3a3789443f15b60135d"
ip = "10.10.32.54"

#本地
# T_key = "0fbe149adf07e5f4afa01a7a4e787fde"
# ip = "10.32.144.73"

tda = TDA(T_key)
tda.SetDataset("ds_r2pi8jxrvhiwjl-l13pp", ip)

#单纯上传数据, 仅上传pcd文件，不填表示上传任何文件
# print(tda.UploadFilesToDataset("/Users/hejinlong/Desktop/毫末", ext=".pcd"))

#上传单个文件
# print(tda.UploadFileToDataset("/Users/hejinlong/Desktop/毫末/pcds/1614562848500000.pcd", basePath="/Users/hejinlong/Desktop/毫末/pcds/"))


#传可视化数据
local_file_path = "/Users/hejinlong/Desktop/数据集测试数据/拉框"
for root, dirs, files in os.walk(local_file_path):
    for filename in files:
        if filename.endswith(".jpg"):

            #文件路径
            pic_file_path = os.path.join(root, filename)

            file = tda.AddFile(pic_file_path, "/Users/hejinlong/Desktop/数据集测试数据/拉框")
            # file = tda.AddFile(pic_file_path)
            file.AddReferId(filename)
            #添加matadata
            file.AddmetaData({
                "myfid":filename,
                "mykey":"myvalue"
            })


            #添加标注结果
            json_path = "/".join([item for item in pic_file_path.split("/")[:-2]]) + "/json/" + filename.replace(".jpg", ".json")
            with open(json_path, "r", encoding="utf-8") as jf:
                jsonData = json.load(jf)
                for mark in jsonData["marks"]:
                    bbox = mark["bbox"]
                    box = {
                        "x": bbox["xmin"],
                        "y": bbox["ymin"],
                        "width": bbox["xmax"] - bbox["xmin"],
                        "height": bbox["ymax"] - bbox["ymin"],
                    }

                    file.AddBox2D(box, label=mark["name"], attrs={"post":mark["post"], "angle":mark["post"]})

# commit 到某个版本
commit = tda.Commit()
print(tda.Upload(commit))

# print(tda.Upload())




from testindatadev.TDA import TDA
import sys
import os
import json
#
# T_key = "0fbe149adf07e5f4afa01a7a4e787fde"
# ip = "10.32.141.220"
# ds = "ds_ihtxzc_uhocslt4fjhrc"

T_key = "492535c229015dcd8de80e2ad64c299b"
ip = "10.10.32.54"
ds = "ds_iilbqah_e38vou0mdd4o"


tda = TDA(T_key)
tda.Debug()
dataset = tda.SetDataset(ds, ip)

# #分页更新
# page = 0
# limit = 100
# i = 0
# while True:
#     offset = page * limit
#     page += 1
#     fileData = tda.GetData(offset, limit)
#     if len(fileData["files"]) <= 0:
#         break
#
#     print(fileData.keys())
#     exit()

    #
    # for file in fileData["files"]:
    #     print(file)
    #     exit()
#         i += 1
#         box = {
#             "x": 10,
#             "y": 10,
#             "width": 100,
#             "height": 100,
#         }
#         file.AddBox2D()
#         print(file.Update())
#         print(i)
#         print(file.fid)
#

#根据fid或者referid更新
file = tda.GetFileAndLabel(fid="fs_y0V4FFBTpvt-y5t2mz_H")

# print(file.ToList())

# print(file.anotations.labels)
# print(file.fid)
# print(file.referId)
# print(file.meta)
# print(file.md5)
# print(file.path)


# file.Update()
# exit()

#新增标注结果

file.referId = "test_refer_id"
file.metaData = {
    "key1":"test_val"
}

file.name = "23333.jpg"

file.sensor = "camera_1"
file.frameId = "test_frame_id"

box = {
    "x": 10,
    "y": 10,
    "width": 100,
    "height": 100,
}

label = "myTestLabelName"

attr = {
    "attrKey1":"attrVal1",
    "attrKey2":"attrVal2",
    "attrKey3":"attrVal3",
}

file.AddBox2D(box, label=label, attrs=attr)

print(file.Update())



import os
import json

from testindatadev.TDA import TDA

#初始化TDA
#测试
T_key = "1f25eddfeefc374a49e7c125341a6b3f"
ip = "10.10.32.54"

#本地
# T_key = "0fbe149adf07e5f4afa01a7a4e787fde"
# ip = "10.32.143.63"

tda = TDA(T_key, True)
tda.SetDataset("ds_iilbqah_e38vou0mdd4o", ip)

#传可视化数据
local_file_path = "/Users/hejinlong/Desktop/数据集测试数据/图像"
for root, dirs, files in os.walk(local_file_path):
    for filename in files:
        if filename.endswith(".jpg"):

            #文件路径
            pic_file_path = os.path.join(root, filename)
            json_file_path = pic_file_path.replace("/pic/", "/json/") + ".json"
            toolType = json_file_path.split("/")[6]


            file = tda.AddFile(pic_file_path, "/Users/hejinlong/Desktop/数据集测试数据/图像/")
            # file = tda.AddFile(pic_file_path)
            file.AddReferId(filename)
#             #添加matadata
            file.AddmetaData({
                "myfid":filename,
                "toolType":toolType,
                "originPath":pic_file_path
            })

            index = 0
            with open(json_file_path, "r", encoding="utf-8") as jf:
                jsonData = json.load(jf)
                if "marks" not in jsonData.keys():
                    file.AddmetaData({
                        "myfid": filename,
                        "toolType": toolType,
                        "originPath": pic_file_path,
                        "markable":False
                    })
                    continue

                for mark in jsonData["marks"]:
                    if mark["type"] == "cuboid":
                        sideCuboid = {
                            "back":[
                                {
                                    "x":mark["finshPoints"][2]["x"],
                                    "y":mark["finshPoints"][2]["y"],
                                },
                                {
                                    "x":mark["finshPoints"][3]["x"],
                                    "y":mark["finshPoints"][3]["y"],
                                },
                            ],
                            "front":[
                                # mark["point"][0], mark["point"][1], mark["point"][2], mark["point"][3]
                                {
                                    "x":mark["finshPoints"][0]["x"],
                                    "y":mark["finshPoints"][0]["y"],
                                },
                                {
                                    "x":mark["finshPoints"][1]["x"],
                                    "y":mark["finshPoints"][0]["y"],
                                },
                                {
                                    "x":mark["finshPoints"][1]["x"],
                                    "y":mark["finshPoints"][1]["y"],
                                },
                                {
                                    "x":mark["finshPoints"][0]["x"],
                                    "y":mark["finshPoints"][1]["y"],
                                }
                            ]
                        }

                        attr = {
                            "type": mark["property"][0][0]["ptitle"],
                            "pname": mark["property"][0][0]["pname"],
                            "pselect": mark["pselect"],
                        }

                        file.AddSideCuboid(sideCuboid, label=mark["property"][0][0]["ptitle"], attrs=attr)
                    elif mark["type"] == "curve":
                        attr = {
                            "type": mark["property"][0][0]["ptitle"],
                            "pname": mark["property"][0][0]["pname"],
                            "pselect": mark["pselect"],
                        }

                        file.AddCurve(mark["point"], label=mark["property"][0][0]["ptitle"], attrs=attr)
                    elif mark["type"] == "point":
                        attr = {
                            "type": mark["property"][0][0]["ptitle"],
                            "pname": mark["property"][0][0]["pname"],
                            "pselect": mark["pselect"],
                        }

                        file.AddPoint(mark["point"], label=mark["property"][0][0]["ptitle"], attrs=attr)
                    elif mark["type"] == "polygon":
                        attr = {
                            "type": mark["property"][0][0]["ptitle"],
                            "pname": mark["property"][0][0]["pname"],
                            "pselect": mark["pselect"],
                        }
                        index += 1
                        file.AddPolygon(mark["point"], label=mark["property"][0][0]["ptitle"], attrs=attr, index=index)
                    elif mark["type"] == "rect":
                        box = {
                            "x": mark["point"]["left"],
                            "y": mark["point"]["top"],
                            "width": mark["point"]["right"] - mark["point"]["left"],
                            "height": mark["point"]["bottom"] - mark["point"]["top"],
                        }

                        attr = {
                            "type":mark["property"][0][0]["ptitle"],
                            "pname":mark["property"][0][0]["pname"],
                            "pselect":mark["pselect"],
                        }

                        file.AddBox2D(box, label=mark["property"][0][0]["ptitle"], attrs=attr)

commit = tda.Commit()
print(tda.Upload(commit))

# print(tda.Upload("6eqv8g0nxibth2c7y3sjfu1l95d4worp"))




import os
import json

from testindatadev.TDA import TDA

#获取数据测试代码

#初始化TDA
T_key = "0fbe149adf07e5f4afa01a7a4e787fde"
tda = TDA(T_key)
tda.SetDataset("ds__tq1wnhun2oged8tbsjy", "10.32.141.220")

#获取数据
# print(tda.GetData())
print(tda.GetData(offset=8, limit=9))#分页查询

#获取数据及标注结果
# print(tda.GetFileAndLabel(fid="fs_uZI662vd-f7UwA-8VK_1"))#根据fid
# print(tda.GetFileAndLabel(fid="fs_N7T02AgYJGF6yxAbk75R"))#根据fid
# print(tda.GetFileAndLabel(ref_id="104.jpg"))#根据ref_id










from testindatadev.TDA import TDA
import sys
import os
import json

# T_key = "0fbe149adf07e5f4afa01a7a4e787fde"
# ip = "10.32.141.220"
# ds = "ds_ihtxzc_uhocslt4fjhrc"

# T_key = "492535c229015dcd8de80e2ad64c299b"
# ip = "10.10.32.54"
# ds = "ds_ge4msswcrghbofy91tuw"

T_key = "bb76998774f7c1347fe347369a4ed470"
ip = "dataset.testin.cn"
ds = "ds_lvsq4xd2obicciiwf6nk"


tda = TDA(T_key)
tda.Debug()
dataset = tda.SetDataset(ds, ip)

path = "/Users/hejinlong/Desktop/数据集测试数据/图像/多边形/pic"

i = 0
for root, dirs, files in os.walk(path):
    for filename in files:
        if filename.endswith(".jpg"):
            filepath = os.path.join(root, filename)
            jsonPath = os.path.join("/Users/hejinlong/Desktop/数据集测试数据/图像/多边形/json", filename + ".json")

            file = tda.AddFile(filepath)

            with open(jsonPath) as jf:
                jsonData = json.load(jf)

                polygonArr = []
                for mark in jsonData["marks"]:
                    polygonArr.append(mark)
                polygonArr.reverse()

                index = 0
                for mark in polygonArr:
                    if mark["type"] == "polygon":
                        attr = {
                            "type": mark["property"][0][0]["ptitle"],
                            "pname": mark["property"][0][0]["pname"],
                            "pselect": mark["pselect"],
                        }
                        index += 1
                        file.AddPolygon(mark["point"], label=mark["property"][0][0]["ptitle"], attrs=attr, index=index)


print(tda.Upload())



import os
import sys
import json
import re

from testindatadev.dataset.dataset import Dataset
from testindatadev.dataset.metadata import MetaData
from testindatadev.dataset.file import File
from testindatadev.dataset.urlfile import UrlFile
from testindatadev.dataset.localdb import LocalDb
from testindatadev.utils import util

#sdk entrance
class TDA():
    def __init__(self, accessKey, host="", debug=False):
        if host == "":
            self.host = "https://dataset.testin.cn/"
        else:
            if "http://" in host or "https://" in host:
                self.host = host.rstrip("/") + "/"
            else:
                self.host = "http://" + host.strip("/") + "/"
        self.__debug = debug
        self.T_key = accessKey
        self.commitFlag = False
        self.commitId = ""
        self.datasetName = ""
        self.fileList = []

    def Debug(self):
        """
        set sdk to debug mod
        """
        self.__debug = True

    @property
    def debug(self):
        return self.__debug

    def SetDataset(self, datasetName):
        """
        Set the dataset to be processed
        datasetName: the name of the dataset
        """
        self.datasetName = datasetName

        if self.debug:
            print(f"\033[0;37;44m[SET_DATASET] dataset: {self.datasetName} , service: {self.host}\033[0m")

        self.dataset = Dataset(self.T_key, datasetName, self.host)

        self.filePrefix = self.datasetName
        if self.dataset.file_path != "":
            self.filePrefix = self.dataset.file_path.strip("/") + "/" + self.datasetName.strip("/")

        if self.dataset.oss_type not in [self.dataset.OSS_TYPE_ALI, self.dataset.OSS_TYPE_QINIU]:
            self.filePrefix = self.dataset.bucket + "/" + self.filePrefix

        # return self.dataset#close for new feature

    def RiseException(self):
        raise Exception("You have not set the dataset name yet!")

    def UploadFilesToDataset(self, rootPath, ext=""):
        """
        Upload files to dataset service directly
        rootPath: local file root path
        ext: if set, files endswith this extension will be uploaded
        """
        if self.debug:
            print(f"[UPLOAD_FILES] upload file to dataset without metedata and annotations!")

        if not self.datasetName:
            self.RiseException()

        total = 0
        for root, dir, files in os.walk(rootPath):
            for fileName in files:
                if fileName.endswith(ext):
                    total += 1

        if self.debug:
            print(f"[UPLOAD_FILES] file total: {total}")

        syncData = []
        j = 0
        i = 0
        retInfo = {'succ': 0, 'fail': 0}
        dirname = os.path.dirname(rootPath.rstrhost("/"))
        
        for root, dir, files in os.walk(rootPath):
            for fileName in files:
                if fileName.endswith(ext):
                    filePath = os.path.join(root, fileName)
                    objectName = filePath.replace(dirname, "").lstrhost("/")
                    self.__UploadFileToDataset(filePath, objectName)
                    tmp = {
                        "ref_id": "",
                        "name": fileName,
                        "path": self.filePrefix + "/" + objectName,
                        "size": int(util.getFileSize(filePath)),
                        "md5": util.getFileMd5(filePath),
                        "frame_id":"",
                        "sensor":"",
                        "meta": {},
                        "anotations": {},
                    }
                    syncData.append(tmp)
                    i += 1
                    if self.debug:
                        per = (i * 100) // total
                        showText = filePath + " =====> " + objectName
                        process = "\r[UPLOAD_FILES][%3s%%]: %s" % (per, showText)
                        print(process)


                    j += 1
                    if j >= 1000:
                        j = 0
                        info = self.dataset.SyncDataToWeb(syncData)
                        if self.debug:
                            print(f"[UPLOAD_FILES] sync data to server, success:{info['succ']}, fail:{info['fail']}")

                        retInfo["succ"] += info["succ"]
                        retInfo["fail"] += info["fail"]
                        syncData = []

        if len(syncData) >= 0:#最后几个没同步的数据
            info = self.dataset.SyncDataToWeb(syncData)
            if self.debug:
                print(f"[UPLOAD_FILES] sync data to server, success:{info['succ']}, fail:{info['fail']}")
            retInfo["succ"] += info["succ"]
            retInfo["fail"] += info["fail"]

        return retInfo

    def UploadFileToDataset(self, filePath):
        """
        Upload one file to dataset service directly
        filePath: local file path
        """
        pathInfo = os.path.split(filePath)
        parentDir = os.path.abspath(os.path.join(pathInfo[0], ".."))
        objectName = pathInfo[0].replace(parentDir, "").strip("/").strip("\\") + "/" + pathInfo[1]
        self.__UploadFileToDataset(filePath, objectName)

        if self.debug:
            print(f"[UPLOAD_ONE_FILE][{filePath}  =====> {objectName}]")

        syncData = {
            "ref_id": "",
            "name": os.path.basename(filePath),
            "path": self.filePrefix+ "/" + objectName,
            "size": int(util.getFileSize(filePath)),
            "md5": util.getFileMd5(filePath),
            "frame_id":"",
            "sensor":"",
            "meta": {},
            "anotations": {},
        }

        info = self.dataset.SyncDataToWeb([syncData])
        if self.debug:
            print(f"[UPLOAD_ONE_FILE] sync data to server, success:{info['succ']}, fail:{info['fail']}")

        return info
        
    def __UploadFileToDataset(self, filePath, objectName):
        """
        Upload one file to OSS
        filePath: local file path
        objectName: OSS object name
        """
        if not self.datasetName:
            self.RiseException()
        return self.dataset.PutFileToDataset(objectName, filePath)

    def AddFile(self, filepath, objectName="", referId="", metaData={}, sensor="", frameId="") -> File:
        """
        Create a File object which is used for visualize data
        filePath: local file path
        objectName: OSS object name
        referId: referId
        metaData: metaData
        sensor: sensor
        frameId: frameId
        """
        if not self.datasetName:
            self.RiseException()

        if self.dataset.hostingMethod == self.dataset.HOSTING_METHOD_OWN_STORAGE:
            raise Exception(f"own hosting type dataset can not add files, you need use AddUrlFile method instead!")

        if not filepath:
            raise Exception(f"filepath must be set")

        file = File(filepath, objectName.strip("/"), self.filePrefix, self.dataset.endpoint, self.dataset.datasetType)
        self.fileList.append(file)
        if self.debug:
            print(f"[ADD FILE] filepath:{filepath}, objectName:{file.objectPath}")

        if referId != "":
            if not type(referId) is str:
                raise Exception(f"referId must be a str, {type(referId)} gavin")
            file.referId = referId

        if metaData != {}:
            file.metadata = MetaData(metaData)

        if sensor != "":
            if not type(sensor) is str:
                raise Exception(f"sensor must be a str, {type(sensor)} gavin")
            file.sensor = sensor

        if frameId != "":
            if not type(frameId) is str:
                raise Exception(f"frameId must be a str, {type(frameId)} gavin")
            file.frameId = frameId

        return file

    def AddUrlFile(self, url, referId="", metaData={}, sensor="", frameId="") -> File:
        """
        Create a UrlFile object which is used for visualize data
        url: fileUrl
        referId: referId
        metaData: metaData
        sensor: sensor
        frameId: frameId
        """
        if not self.datasetName:
            self.RiseException()

        if self.dataset.hostingMethod != self.dataset.HOSTING_METHOD_OWN_STORAGE:
            raise Exception(f"cloud-hosting type dataset can not add url files, you need use AddFile method instead!")

        if not url:
            raise Exception(f"url must be set")

        file = UrlFile(url,  self.dataset.datasetType)
        self.fileList.append(file)
        if self.debug:
            print(f"[ADD URL FILE] url:{url}")

        if referId != "":
            if not type(referId) is str:
                raise Exception(f"referId must be a str, {type(referId)} gavin")
            file.referId = referId

        if metaData != {}:
            file.metadata = MetaData(metaData)

        if sensor != "":
            if not type(sensor) is str:
                raise Exception(f"sensor must be a str, {type(sensor)} gavin")
            file.sensor = sensor

        if frameId != "":
            if not type(frameId) is str:
                raise Exception(f"frameId must be a str, {type(frameId)} gavin")
            file.frameId = frameId

        return file

    def Commit(self, commitId = ""):
        """
        commit a dataset data
        commitId: if set, this commit will add to the committed data before
        """
        if not self.datasetName:
            self.RiseException()

        db = LocalDb(commitId)
        if self.debug:
            if commitId:
                print(f"[COMMIT FILE] with commitId:{commitId}")
            else:
                print(f"[COMMIT FILE] without commitId!")

            print(f"[COMMIT FILE] begin insert data to local db")

        if len(self.fileList) <= 0:
            raise Exception("you should add 1 file at least")

        db.insertVal(self.fileList)

        if self.debug:
            print(f"[COMMIT FILE] end insert data to local db")

        db.close()

        self.commitFlag = True
        self.commitId = db.commitId
        return db.commitId

    def Upload(self, commitId = ""):
        """
        upload a committed dataset data and sync annotations to the testin-dataser server
        commitId: if set, this commit will be upload and snync
        """
        if not self.datasetName:
            self.RiseException()

        if commitId != "":
            if self.debug:
                print(f"[UPLOAD_VISUALIZE_FILE] upload visualize files to dataset with committed data: {self.commitId}")
            self.commitFlag = True
            self.commitId = commitId

        if not self.commitFlag:
            self.commitId = self.Commit(commitId)
            if self.debug:
                print(f"[UPLOAD_VISUALIZE_FILE] upload visualize files to dataset without commit, auto commit:{self.commitId}")

        if not self.commitId:
            self.commitId = self.Commit(commitId)
            if self.debug:
                print(f"[UPLOAD_VISUALIZE_FILE] upload visualize files to dataset without commit, auto commit:{self.commitId}")

        db = LocalDb(self.commitId)
        allData = db.fetchAll()
        total = len(allData)
        if total <= 0:
            raise Exception("you should add 1 file at least")

        if self.debug:
            print(f"[UPLOAD_FILES]files total count: {total}")

        syncData = []
        i = 0
        j = 0
        retInfo = {'succ': 0, 'fail': 0}
        for data in allData:

            if data["filepath"] != "" and data["objectPath"] != "":
                self.__UploadFileToDataset(data["filepath"], data["objectPath"])

            tmp = {
                "ref_id":data["referid"],
                "name":data["filename"],
                "path":data["osspath"],
                "size":data["filesize"],
                "md5":data["md5"],
                "frame_id":data["frame_id"],
                "sensor":data["sensor"],
                "meta":json.loads(data["metadata"]),
                "anotations":json.loads(data["labeldata"]),
            }
            syncData.append(tmp)
            i += 1
            j += 1

            if self.debug:
                per = (j * 100) // total
                showText = data['filepath'] + " =====> " + data['objectPath']
                process = f"\r[UPLOAD_FILES][{self.commitId}][%3s%%]: %s" % (per, showText)
                print(process)

            if i >= 100:
                i = 0
                info = self.dataset.SyncDataToWeb(syncData)
                if self.debug:
                    print(f"[UPLOAD_FILES] sync data to server, success:{info['succ']}, fail:{info['fail']}")
                retInfo["succ"] += info["succ"]
                retInfo["fail"] += info["fail"]
                syncData = []


        if len(syncData) >= 0:#最后几个没同步的数据
            info = self.dataset.SyncDataToWeb(syncData)
            if self.debug:
                print(f"[UPLOAD_FILES] sync data to server, success:{info['succ']}, fail:{info['fail']}")
            retInfo["succ"] += info["succ"]
            retInfo["fail"] += info["fail"]

        db.clearCache()

        return retInfo

    def GetData(self, offset=0, limit=100, metaKey="", metaValue="", label="", sensor=""):
        """
        search data from testin-dataset service by criteria
        offset: offset of the search result
        limit: numbers of the search result
        metaKey: which metadata key you would like to use to search 
        metaValue: set metadata value to your search  metadata key, if metaKey is not set, metaValue will be ignore
        label: search by label
        sensor: search by sensor
        all above criteria will be juxtaposition
        """
        if limit > 1000:
            raise Exception("limit must less than 1000")

        if (metaKey == "" and metaValue != "") or (metaKey != "" and metaValue == ""):
            raise Exception("both metaKey and metaValue are must set at the same time")

        return self.dataset.GetData(offset, limit, metaKey=metaKey, metaValue=metaValue, label=label, sensor=sensor, debug=self.debug)

    def GetFileAndLabel(self, fid="", referId=""):
        """
        search data from testin-dataset service by fid or ref_id
        fid: fid
        ref_id: referid you set when you upload data to testin-dataset service
        """
        if fid == "" and referId == "":
            raise Exception("fid or ref_id must be set")

        if fid:
            return self.dataset.GetFileAndLabelByFid(fid, debug=self.debug)

        return self.dataset.GetFileAndLabelByReferid(referId, debug=self.debug)





